@@ -7,9 +7,12 @@ This module contains the core functions required to create an import hook.
 import ast
 import os
 import sys
+import traceback
 
 from importlib.abc import Loader, MetaPathFinder
 from importlib.util import spec_from_file_location, decode_source
+from types import CodeType, ModuleType
+from typing import Callable, Dict, Sequence, Optional, Any
 
 from . import console
 from .session import config
@@ -171,12 +174,17 @@ class IdeasLoader(Loader):  # pylint: disable=R0902
         original_source = source
 
         if self.transform_source is not None:
-            source = self.transform_source(
-                source,
-                filename=self.filename,
-                module=module,
-                callback_params=self.callback_params,
-            )
+            try:
+                source = self.transform_source(
+                    source,
+                    filename=self.filename,
+                    module=module,
+                    callback_params=self.callback_params,
+                )
+            except Exception as exc:
+                print("Error when executing transform_source:")
+                print("   ", traceback.format_exception_only(type(exc), exc)[0].strip())
+                return
 
         if config.show_changes and original_source != source:
             print_source(original_source, header="Original")
@@ -187,18 +195,18 @@ class IdeasLoader(Loader):  # pylint: disable=R0902
 
         try:
             tree = ast.parse(source, self.filename)
-        except Exception as exc:
+        except Exception:
             print("Exception raised while parsing source.")
-            raise exc
+            raise
 
         if self.transform_ast is not None:
             tree = self.transform_ast(tree)
 
         try:
             code_object = compile(tree, self.filename, "exec")
-        except Exception as exc:
+        except Exception:
             print("Exception raised while compiling tree.")
-            raise exc
+            raise
 
         if self.transform_bytecode is not None:
             code_object = self.transform_bytecode(code_object)
@@ -214,26 +222,26 @@ class IdeasLoader(Loader):  # pylint: disable=R0902
         else:
             try:
                 exec(code_object, module.__dict__)  # pylint: disable=W0122
-            except Exception as exc:
+            except Exception:
                 print("Exception raised while executing code object.")
-                raise exc
+                raise
 
 
 def create_hook(
-    callback_params=None,
-    create_module=None,
-    console_dict=None,
-    exec_=None,
-    extensions=None,
-    first=True,
-    hook_name=None,
-    ipython_ast_node_transformer=None,
-    module_class=None,
-    source_init=None,
-    transform_ast=None,
-    transform_bytecode=None,
-    transform_source=None,
-):  # pylint: disable=R0913,R0914
+    callback_params: Optional[Dict[str, Any]] = None,
+    create_module: Optional[Callable[..., ModuleType]] = None,
+    console_dict: Optional[Dict[str, Any]] = None,
+    exec_: Optional[Callable[..., None]] = None,
+    extensions: Optional[Sequence[str]] = None,
+    first: bool = True,
+    hook_name: Optional[str] = None,
+    ipython_ast_node_transformer: Optional[ast.NodeTransformer] = None,
+    module_class: Optional[type] = None,
+    source_init: Optional[Callable[[], str]] = None,
+    transform_ast: Optional[ast.NodeTransformer] = None,
+    transform_bytecode: Optional[Callable[[CodeType], CodeType]] = None,
+    transform_source: Optional[Callable[[str], str]] = None,
+) -> IdeasMetaFinder:  # pylint: disable=R0913,R0914
     """Function to facilitate the creation of an import hook.
 
     Each of the following parameter is optional; most of these are
