@@ -3,15 +3,20 @@ configuration choice during a single run/session."""
 
 
 class State:
+    """Keeps track of various configuration parameters"""
+
     def __init__(self):
         self.console_name = "Ideas Console"
         self.show_original = False
-        self.show_transformed = False
         self.current_file = ""
         self.active_console = False
         self.original = ""
+        self.verbose_finder = False
+        self.show_changes = False
 
     def print_original(self, source, header="Original"):
+        """Depending on configuration, can print the original source
+        code of a module that was imported."""
         self.original = source
         if self.active_console:
             return
@@ -22,7 +27,10 @@ class State:
         print("-----------------------------")
 
     def print_transformed(self, source, header="Transformed"):
-        if not self.show_transformed:
+        """Depending on the configuration, can print the transformed
+        output if it differs from the original source.
+        """
+        if not self.show_changes:
             return
         if source == self.original:
             return
